==> absfuyu_res-0.0.2.tar.gz: absfuyu_res-0.0.2/README.md <==
<div align="center">
	<h1 align="center">
		<img src="https://github.com/AbsoluteWinter/AbsoluteWinter.github.io/blob/main/absfuyu/images/repository-image-crop.png?raw=true" alt="absfuyu"/>
	</h1>
	<p align="center">
		<a href="https://pypi.org/project/absfuyu-res/"><img src="https://img.shields.io/pypi/dm/absfuyu-res?style=flat-square" alt="pypi"/></a>
		<a href="https://pypi.org/project/absfuyu-res/"><img src="https://img.shields.io/pypi/v/absfuyu-res?style=flat-square" /></a>
		<a><img src="https://img.shields.io/badge/license-MIT-blue?style=flat-square" /></a>
	</p>
</div>


---

## **SUMMARY:**

*TL;DR: A collection of code*

## **INSTALLATION:**

```bash
$ pip install -U absfuyu
```

## **USAGE:**

```python
import absfuyu
help(absfuyu)
```

## **DOCUMENTATION:**

> [here](https://absolutewinter.github.io/absfuyu/)



## **LICENSE:**

```
MIT License

Copyright (c) 2023 AbsoluteWinter

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

==> absfuyu_res-0.0.3.tar.gz: absfuyu_res-0.0.3/README.md <==
<div align="center">
	<h1 align="center">
		<img src="https://github.com/AbsoluteWinter/AbsoluteWinter.github.io/blob/main/absfuyu/images/repository-image-crop.png?raw=true" alt="absfuyu"/>
	</h1>
	<p align="center">
		<a href="https://pypi.org/project/absfuyu-res/"><img src="https://img.shields.io/pypi/dm/absfuyu-res?style=flat-square" alt="pypi"/></a>
		<a href="https://pypi.org/project/absfuyu-res/"><img src="https://img.shields.io/pypi/v/absfuyu-res?style=flat-square" /></a>
		<a><img src="https://img.shields.io/badge/license-MIT-blue?style=flat-square" /></a>
	</p>
</div>


---

## **SUMMARY:**

*TL;DR: A collection of code*

## **INSTALLATION:**

```bash
$ pip install -U absfuyu-res
```


## **LICENSE:**

```
MIT License

Copyright (c) 2023 AbsoluteWinter

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
